FILENAME_METADATA_JSON = "model_metadata.omlmd.json"
FILENAME_METADATA_YAML = "model_metadata.omlmd.yaml"
MIME_APPLICATION_CONFIG = "application/x-config"
MIME_APPLICATION_MLMODEL = "application/x-mlmodel"
